@@ -3,6 +3,7 @@ from typing import Any, Dict, Optional
 
 import numpy as np
 
+from ..utils.type_hints import NDArray
 from .base import IReader
 
 
@@ -25,7 +26,7 @@ class NpyReader(IReader):
         super().__init__(input_key, output_key or input_key)
         self.rootpath = rootpath
 
-    def __call__(self, element: Dict[str, Any]) -> Dict[str, np.ndarray]:
+    def __call__(self, element: Dict[str, Any]) -> Dict[str, NDArray]:
         """Read a row from your annotations dict with filename and transfer it to an array.
 
         Args:
